@@ -24,5 +24,7 @@ NumericVector layerSunlitFraction(NumericMatrix LAIme, NumericMatrix LAImd, Nume
 
 List instantaneousLightExtinctionAbsortion(NumericMatrix LAIme, NumericMatrix LAImd, NumericMatrix LAImx, 
                                            NumericVector kPAR, NumericVector alphaSWR, NumericVector gammaSWR,
-                                           DataFrame ddd, NumericVector LWR_diffuse, 
-                                           int ntimesteps = 24, String canopyMode= "sunshade", double trunkExtinctionFraction = 0.1);
+                                           DataFrame ddd, int ntimesteps = 24, double trunkExtinctionFraction = 0.1);
+
+List longwaveRadiationSHAW(NumericMatrix LAIme, NumericMatrix LAImd, NumericMatrix LAImx, 
+                           double LWRatm, double Tsoil, NumericVector Tair, double trunkExtinctionFraction = 0.1);
